# -*- coding: utf-8 -*-
NAME = 'ip2location-python'
DESCRIPTION = 'ipv4 to location'
VERSION = '0.1.2'
AUTHOR = 'pengyao'
AUTHOR_EMAIL = 'pengyao@pengyao.org'
COPYRIGHT = 'Copyright © 2015 ' + AUTHOR
LICENCE = 'Apache License V2.0'
URL = 'https://github.com/pengyao/ip2location-python'
